@@ -1,5 +1,5 @@
 #
-# SQLite.py - Ed Bartosh <bartosh@gmail.com>, <Peter.Bienstman@UGent.be>
+# SQLite.py - Ed Bartosh <bartosh@gmail.com>, <Peter.Bienstman@gmail.com>
 #
 
 import os
@@ -1553,9 +1553,10 @@ _("Putting a database on a network drive is forbidden under Windows to avoid dat
     def cards_due_for_ret_rep(self, timestamp, sort_key="", limit=-1):
         sort_key = self._process_sort_key(sort_key)
         return ((cursor[0], cursor[1]) for cursor in self.con.execute("""
-            select _id, _fact_id from cards where
-            active=1 and grade>=2 and ?>=next_rep order by %s limit ?"""
-            % sort_key, (timestamp, limit)))
+            select _id, _fact_id from cards where active=1 and grade>=2
+            and ?>=next_rep and ret_reps_since_lapse<=? order by %s limit ?"""
+            % sort_key, (timestamp,
+            self.config()["max_ret_reps_since_lapse"], limit)))
 
     def cards_to_relearn(self, grade, sort_key="", limit=-1):
         sort_key = self._process_sort_key(sort_key)
@@ -1582,8 +1583,10 @@ _("Putting a database on a network drive is forbidden under Windows to avoid dat
         sort_key = self._process_sort_key(sort_key)
         return ((cursor[0], cursor[1]) for cursor in self.con.execute("""
             select _id, _fact_id from cards where
-            active=1 and grade>=2 and ?<next_rep order by %s limit ?"""
-            % sort_key, (timestamp, limit)))
+            active=1 and grade>=2 and ?<next_rep and ret_reps_since_lapse<=? 
+            order by %s limit ?"""
+            % sort_key, (timestamp,
+            self.config()["max_ret_reps_since_lapse"], limit)))
 
     def recently_memorised_count(self, max_ret_reps):
         return self.con.execute("""select count() from cards where active=1
@@ -1602,7 +1605,7 @@ _("Putting a database on a network drive is forbidden under Windows to avoid dat
                                   limit=-1, max_ret_reps=-1):
         sort_key = self._process_sort_key(sort_key)
         extra_cond = "" if max_ret_reps == -1 else str(
-            "and acq_reps>0 and ret_reps between 1 and " + str(max_ret_reps))
+            "and acq_reps>0 and ret_reps between 0 and " + str(max_ret_reps))
         return ((cursor[0], cursor[1]) for cursor in self.con.execute("""
             select _id, _fact_id from cards where active=1 and scheduler_data=?
             %s order by %s limit ?"""
@@ -1610,7 +1613,7 @@ _("Putting a database on a network drive is forbidden under Windows to avoid dat
 
     def scheduler_data_count(self, scheduler_data, max_ret_reps=-1):
         extra_cond = "" if max_ret_reps == -1 else str(
-            "and acq_reps>0 and ret_reps between 1 and " + str(max_ret_reps))
+            "and acq_reps>0 and ret_reps between 0 and " + str(max_ret_reps))
         return self.con.execute("""select count() from cards
             where active=1 and scheduler_data=? %s """ % extra_cond,
             (scheduler_data, )).fetchone()[0]
