@@ -1,14 +1,11 @@
 #
-# google_pronouncer.py <Peter.Bienstman@UGent.be>
+# google_pronouncer.py <Peter.Bienstman@gmail.com>
 #
 
-from gtts import gTTS
-
 from mnemosyne.libmnemosyne.gui_translator import _
 from mnemosyne.libmnemosyne.utils import expand_path
 from mnemosyne.libmnemosyne.pronouncer import Pronouncer
 
-
 class GooglePronouncer(Pronouncer):
 
     used_for = "bn", "bn-BD", "bn-ID", "zh", "zh-CN", "zh-TW", "cs", "da", \
@@ -26,12 +23,15 @@ class GooglePronouncer(Pronouncer):
 
         """Returns a temporary filename with the audio."""
 
+        # Lazy import to speed things up.
+        from gtts import gTTS
+
         language_id = self.config().card_type_property(\
             "sublanguage_id", card_type)
         if not language_id:
             language_id = self.config().card_type_property(\
                 "language_id", card_type)
-        tts = gTTS(foreign_text, language_id)
+        tts = gTTS(foreign_text, lang=language_id)
         filename = expand_path("__GTTS__TMP__.mp3", self.database().media_dir())
         tts.save(filename)
         return filename
