@@ -1,10 +1,11 @@
 #
-# default_render_chain.py <Peter.Bienstman@UGent.be>
+# default_render_chain.py <Peter.Bienstman@gmail.com>
 #
 
 from mnemosyne.libmnemosyne.filters.latex import Latex
 from mnemosyne.libmnemosyne.render_chain import RenderChain
 from mnemosyne.libmnemosyne.renderers.html_css import HtmlCss
+from mnemosyne.libmnemosyne.filters.furigana import Furigana
 from mnemosyne.libmnemosyne.filters.RTL_handler import RTLHandler
 from mnemosyne.libmnemosyne.filters.html5_audio import Html5Audio
 from mnemosyne.libmnemosyne.filters.html5_video import Html5Video
@@ -26,6 +27,6 @@ class DefaultRenderChain(RenderChain):
     id = "default"
 
     filters = [Latex, EscapeToHtml, ExpandPaths, Html5Audio, Html5Video,
-               RTLHandler, NonLatinFontSizeIncrease]
+               RTLHandler, Furigana, NonLatinFontSizeIncrease]
     renderers = [HtmlCss]
 
