@@ -1,5 +1,5 @@
 #
-# SM2_mnemosyne.py <Peter.Bienstman@UGent.be>
+# SM2_mnemosyne.py <Peter.Bienstman@gmail.com>
 #
 
 import time
@@ -33,7 +33,7 @@ class SM2Mnemosyne(Scheduler):
     """
 
     name = "SM2 Mnemosyne"
-    _warned_about_too_many_cards = False  # default false
+    _warned_about_too_many_cards = False
 
     def true_scheduled_interval(self, card):
 
@@ -280,8 +280,8 @@ _("You appear to have missed some reviews. Don't worry too much about this backl
                         else:
                             self.stage = 3
                         return
-            # If the queue is close to empty, start pulling in sister cards.
-            if len(self._fact_ids_in_queue) <= 2:
+            # If our hand is not full enough, start pulling in sister cards.
+            if non_memorised_in_queue < limit:
                 for _card_id, _fact_id in db.cards_unseen(\
                         sort_key=sort_key, limit=min(limit, 50)):
                     if _fact_id not in self._fact_ids_in_queue:
@@ -487,6 +487,10 @@ _("You appear to have missed some reviews. Don't worry too much about this backl
         # Allow plugins to modify new_interval by multiplying it.
         new_interval *= self.interval_multiplication_factor(card, new_interval)
         new_interval = int(new_interval)
+        # Optional: limit interval:
+        if self.config()["max_scheduled_interval_days"]:
+            if new_interval > self.config()["max_scheduled_interval_days"] * DAY:
+                new_interval = self.config()["max_scheduled_interval_days"] * DAY    
         # When doing a dry run, stop here and return the scheduled interval.
         if dry_run:
             return new_interval
