@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 
 # Mnemosyne CGI upload server.
 # Based on code by JeffBauer@bigfoot.com, Aaron Watters, Jim Fulton
@@ -26,8 +26,8 @@ class FileUploadAcquisition:
         uf = fs["file"]
 
         filename = os.path.join("/home/mnemosyne", uf.filename)
-        if os.path.exists(filename):
-            return
+        #if os.path.exists(filename):
+        #    return
         f = file(filename, "wb")
         while 1:
             line = uf.file.readline()
